@@ -58,7 +58,7 @@ class Exceptions:
 
 class OutpostsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html)
     """
 
@@ -74,7 +74,7 @@ class OutpostsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#can_paginate)
         """
 
@@ -84,12 +84,12 @@ class OutpostsClient(BaseClient):
         OutpostIdentifier: str,
         LineItems: Sequence["LineItemRequestTypeDef"],
         PaymentOption: PaymentOptionType,
-        PaymentTerm: Literal["THREE_YEARS"] = None
+        PaymentTerm: Literal["THREE_YEARS"] = ...
     ) -> CreateOrderOutputTypeDef:
         """
         Creates an order for an Outpost.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.create_order)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.create_order)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#create_order)
         """
 
@@ -98,15 +98,15 @@ class OutpostsClient(BaseClient):
         *,
         Name: str,
         SiteId: str,
-        Description: str = None,
-        AvailabilityZone: str = None,
-        AvailabilityZoneId: str = None,
-        Tags: Mapping[str, str] = None
+        Description: str = ...,
+        AvailabilityZone: str = ...,
+        AvailabilityZoneId: str = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateOutpostOutputTypeDef:
         """
         Creates an Outpost.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.create_outpost)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.create_outpost)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#create_outpost)
         """
 
@@ -114,7 +114,7 @@ class OutpostsClient(BaseClient):
         """
         Deletes the Outpost.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.delete_outpost)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.delete_outpost)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#delete_outpost)
         """
 
@@ -122,21 +122,21 @@ class OutpostsClient(BaseClient):
         """
         Deletes the site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.delete_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.delete_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#delete_site)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#generate_presigned_url)
         """
 
@@ -144,43 +144,41 @@ class OutpostsClient(BaseClient):
         """
         Gets information about the specified Outpost.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.get_outpost)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.get_outpost)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#get_outpost)
         """
 
     def get_outpost_instance_types(
-        self, *, OutpostId: str, NextToken: str = None, MaxResults: int = None
+        self, *, OutpostId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> GetOutpostInstanceTypesOutputTypeDef:
         """
         Lists the instance types for the specified Outpost.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#get_outpost_instance_types)
         """
 
     def list_outposts(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        LifeCycleStatusFilter: Sequence[str] = None,
-        AvailabilityZoneFilter: Sequence[str] = None,
-        AvailabilityZoneIdFilter: Sequence[str] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        LifeCycleStatusFilter: Sequence[str] = ...,
+        AvailabilityZoneFilter: Sequence[str] = ...,
+        AvailabilityZoneIdFilter: Sequence[str] = ...
     ) -> ListOutpostsOutputTypeDef:
         """
         Create a list of the Outposts for your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.list_outposts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.list_outposts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#list_outposts)
         """
 
-    def list_sites(
-        self, *, NextToken: str = None, MaxResults: int = None
-    ) -> ListSitesOutputTypeDef:
+    def list_sites(self, *, NextToken: str = ..., MaxResults: int = ...) -> ListSitesOutputTypeDef:
         """
         Lists the sites for the specified AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.list_sites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.list_sites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#list_sites)
         """
 
@@ -188,7 +186,7 @@ class OutpostsClient(BaseClient):
         """
         Lists the tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#list_tags_for_resource)
         """
 
@@ -196,7 +194,7 @@ class OutpostsClient(BaseClient):
         """
         Adds tags to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#tag_resource)
         """
 
@@ -204,6 +202,6 @@ class OutpostsClient(BaseClient):
         """
         Removes tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/outposts.html#Outposts.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/outposts.html#Outposts.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/client.html#untag_resource)
         """
